@@ -646,10 +646,9 @@ def get_readonly_fsa(desc_string, rp):
 	the security module.
 
 	"""
-	if os.name == 'nt' and (desc_string == 'source' or
-			desc_string == 'rdiff-backup repository'):
+	if os.name == 'nt':
 		log.Log("Hardlinks disabled by default on Windows", 4)
-		Globals.set('preserve_hardlinks', 0)
+		SetConnections.UpdateGlobal('preserve_hardlinks', 0)
 	return FSAbilities(desc_string).init_readonly(rp)
 
 class SetGlobals:
